kenchi\.outlier\_detection\.empirical\_distns module
====================================================

.. automodule:: kenchi.outlier_detection.empirical_distns
    :members:
    :undoc-members:
    :show-inheritance:
